@@ -8,7 +8,7 @@ class ModelVocabulary:
         self.vocabulary = vocabulary
         self.tokenizer = tokenizer
 
-    def len(self) -> int:
+    def __len__(self) -> int:
         """" Returns the length of the vocabulary """
         return len(self.vocabulary)
 
