@@ -13,12 +13,6 @@ class ReinventCoreAdapter(GenerativeModelBase):
         self.network =  self.generative_model.network
         # self._nll_loss =  self._reinvent_model._nll_loss
 
-    #TODO: this should not be part of the interface
-    def load_from_file(self, path, mode=ModelModeEnum().TRAINING):
-        model_mode = ModelModeEnum()
-        mode = mode == model_mode.INFERENCE
-        return self.generative_model.load_from_file(path, mode=mode)
-
     def save_to_file(self, path):
         self.generative_model.save(path)
 
@@ -26,4 +20,10 @@ class ReinventCoreAdapter(GenerativeModelBase):
         return self.generative_model.likelihood(sequences)
 
     def sample(self, num, batch_size):
-        return self.generative_model.sample_smiles(num, batch_size)
\ No newline at end of file
+        return self.generative_model.sample_smiles(num, batch_size)
+
+    def get_network_parameters(self):
+        return self.generative_model.get_network_parameters()
+
+    def get_vocabulary(self):
+        return self.vocabulary
